/* RealSpeak.h

Header file for RealSpeak.cpp

Part of the caiviar package. 

Copyright (c) 2002 MobileX AG, http://www.mobilexag.de
Copyright (c) 2002 Peter Dikant <peter.dikant@mobilexag.de>
Copyright (c) 2002 Matthias Kramm <kramm@quiss.org>

This file is distributed under the GPL, see file COPYING for details. */

#ifdef WIN32
#include <windows.h>
#endif
#include "ttsso_types.h"
#include "lh_ttsso.h"
#include "../src/Log.h"
#include "../src/os.h"

#ifndef __realspeak_h__
#define __realspeak_h__

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

class RealSpeak: public TextToSpeech
{
public:
	static int initialize(Logger*log);
	static void finalize(Logger*log);
	
	static int setParams (const char *key, const char* value);

	virtual void text2Stream (const char *text, unsigned char **outbuffer, unsigned long *size);
	virtual void text2File (const char *text, const char *filename);
	virtual void text2Audio (const char *text);
	RealSpeak(Logger *log);
	virtual ~RealSpeak();

private:
	static TTSRETVAL sourceCallback(void *pAppData, void *databuffer, U32 buffersize, U32 *datasize);
	static VOID *destCallback(void *pAppData, U16 datatype, VOID *data, U32 datasize, U32 *buffersize);
	static TTSRETVAL CbTtsEventNotify(void *pAppData, void *buffer, U16 datasize, U16 event);
	void loadDictionary(const char* dictionary);
	HTTSINSTANCE hInst;
	TTSPARM ttsParm;
	HTTSDICT userdict;
	char* text;
	char* textstart;
	unsigned char *output;
	long outputPos;
	long outputSize;
	Mutex mutex;
	long int outputsize;

	static char* dictionary; //set by setParam, used by constructor
	static char* remote_server;
	static char* remote_service;
	static int remote_port;
	static char* language;
	static char* voice;
};

#endif
