/* TextToSpeech.h

Generic interface for TTS implementations.

Part of the caiviar package. 

Copyright (c) 2002 MobileX AG, http://www.mobilexag.de
Copyright (c) 2002 Matthias Kramm <kramm@mobilexag.de>

This file is distributed under the GPL, see file COPYING for details. */

#ifndef __text2speech__
#define __text2speech__

#include "../config.h"
#include "../src/Log.h"

class TextToSpeech
{
public:
	static TextToSpeech* getImplementation(Logger * log);

	/* called on program initialization, after all params have been set via setParams() */
	static int initialize(Logger*log);
	/* called on program exit */
	static void finalize(Logger*log);

	/* sets a parameter, e.g. realspeak.dictionary to value */
	static int setParams (const char *key, const char*value);
	
	/* constructor is called for each new thread which uses TTS (i.e., every thread has
	 it's own TTS class */
	TextToSpeech(Logger *log);
	/* called upon thread exit */
	virtual ~TextToSpeech();

	/* audio routines, at least text2Stream must be implemented */
	virtual void text2Stream (const char *text, unsigned char **outbuffer, unsigned long *size);
	virtual void text2File (const char *text, const char *filename);
	virtual void text2Audio (const char *text);
protected:
	Logger * log;
};

#endif
